import BasicLayout from '@/layouts/home'

/**
 * 读取./modules下的所有js文件并注册模块
 */
const requireModule = require.context('./modules', false, /\.js$/)
const modules = []
requireModule.keys().forEach(fileName => {
  modules.push(requireModule(fileName).default)
})
const frameIn = [
    // 默认路由配置
    {
        path: "/",
        redirect: "/login"
    },
    {
        path: "/",
        component: () => BasicLayout,
        meta: { title: "首页" },
        children: []
    },
    ...modules
];

/**
 * 在主框架之外显示
 */

const frameOut = [
    // 登录
    {
        path: "/login",
        name: "login",
        meta: {
            title: "登录"
        },
        component: () => import("@/pages/account/login")
    },
    {
        path: "/redirect",
        name: "redirect",
        component: () => import("@/pages/account/redirect")
    },
    {
      name: `matchPreview`,
      path: `/match/preview`,
      component: () => import("@/pages/match/preview"),
      meta: { title: "赛事预览" }
    }
];
/**
 * 错误页面
 */

const errorPage = [
    {
        path: '/403',
        name: '403',
        meta: {
            title: '403'
        },
        component: () => import('@/pages/exception/error/403')
    },
    {
        path: '*',
        name: '404',
        meta: {
            title: '404'
        },
        component: () => import('@/pages/exception/error/404')
    }
]

// 重新组织后导出
export default [
    ...frameIn,
    ...frameOut,
    ...errorPage
];