/**
 * 业务配置
 * */
const url = location.host;
const isDev = process.env.NODE_ENV === "development"; // 开发环境
const isHh = url.includes("10.196.131.73"); //河海版本
const isCH = url.includes("124.71.12.62"); //巢湖版本
const isPro = url.includes("occupationlab.com"); //职站生产
const isZxy = url.includes("izhixinyun.com"); //智信云
const isTest = url.includes('121.37.12.51'); //中台测试服

let bankPath = `${location.origin}/banksystem` // 银行系统地址
let jumpPath = `${location.origin}/judgmentPoint`
let host = `${location.origin}/`
let uploadURL = `${location.origin}/`
let title = (isHh || isCH) ? '教师管理端' : '职站服务端管理系统'

if (isPro) {
    bankPath = `https://www.huorantech.cn/banksystem`
    // 职站生产
    uploadURL = `https://www.huorantech.cn/`
    jumpPath = `https://www.huorantech.cn/judgmentPoint/`
} else if (isDev) {
    jumpPath = `http://${location.hostname}:8087/`
    bankPath = `http://${location.hostname}:8093`
    uploadURL = `http://121.37.12.51/`
    host = "http://121.37.12.51/"; // 中台测试服
    // host = 'https://www.occupationlab.com/' // 正式服
    // host = "http://192.168.31.151:9000/"; // 榕
    // host = 'http://192.168.31.52:9000/'; // 赓
}

const Setting = {
    /**
     * 基础配置
     * */
    platformId: 1, // 平台标识，1职站，2数据平台，3中台
    platformType: 0, // 平台端区分：0->教师端 1->学生端 2->无端
    platformSource: 1, // 平台来源(0中台，1职站)
    titleSuffix: title, // 网页标题的后缀
    routerMode: "hash", // 路由模式，可选值为 history 或 hash
    showProgressBar: true, // 页面切换时，是否显示模拟的进度条
    apiBaseURL: host, // 接口请求地址
    jumpPath, // 判分点系统前缀
    autoLogoutTime: 3600000, // 长时间未操作，自动退出登录时间
    projectData: "sta_data", // 新增项目跳转判分点数据存储cookie的key
    modalDuration: 3, // 接口请求返回错误时，弹窗的持续时间，单位：秒
    errorModalType: "Message", // 接口请求返回错误时，弹窗的类型，可选值为 Message 或 Notice
    cookiesExpires: 1, // Cookies 默认保存时间，单位：天
    tokenExpires: 1296000000, // token在localStorage的时间(毫秒)
    bankPath,
    isDev,
    isTest,
    isPro,
    /**
     * 路由白名单
     * */
    whiteList: ['/login', '/redirect'],
    /**
     * localStorage里保存的token的key
     */
    tokenKey: "oc_server_token",
    /**
     * localStorage里保存的vuex的key
     */
    storeKey: "oc_server_store",
    /**
     * 默认密码
     */
    initialPassword: "1122aa",
    /**
     * 多语言配置
     * */
    i18n: {
        // 默认语言
        default: "zh",
        // 是否根据用户电脑配置自动设置语言（仅第一次有效）
        auto: false
    },
    /**
     * 布局配置
     * */
    layout: {},
    /**
     * 功能配置
     * */
    // 相同路由，不同参数间进行切换，是否强力更新
    sameRouteForceUpdate: false,
    // 是否使用动态路由(即角色权限,开启了的话就会取后端返回的权限树来显示头部导肮和页面按钮)
    dynamicRoute: true,
    // 文件上传
    upload: {
        apiURL: uploadURL,
        maxSize: 30
    }
};

export default Setting;
